Module array_tuple_ext

Module array_tuple_ext 

Extension traits for array tuple syntax support Extension traits for array tuple syntax support with hashbrown

This module provides extension traits that enable the clean array tuple syntax for collection types when the array-tuples feature is enabled.